% Main program for  paper A.K. Singh, A. Jayaraman, and J. Hahn. Modeling
% Regulatory Mechanisms in IL-6 Signal Transduction in Hepatocytes. Biotechnology & Bioengineering 95, No. 5, pp. 850-862
% To whom correspondence should be addressed. Juergen Hahn, Tel.: (979) 845 3568, Fax: (979) 845 6446, e-mail: hahn@tamu.edu

close all
clc
clear all


global kf0 kr0 kf1 kr1 kf2 kr2 kf3 kr3 k4 kf5 kr5 k6 kf7 kr7 kf8 kr8 kf9 kr9 k10 kf11 kr11 k12 kf13 kr13 k14 kf15 kr15 k16 k17 k18a k18b k19 k20
global kf21 kr21 k22 k23 k24f k24r k25f k25r k26f k26r k27f k27r k28f k28r k29f k29r k30f k30r k31f k31r k32f k32r k33f k33r k34f k34r k35f k35r
global vm km k37f k37r k38f k38r k39f k39r k40f k40r k41f k41r k42f k42r k43 k44f k44r k45 k46f k46r k47 k48f k48r k49 k50f k50r k51 k52f k52r
global k53 k54f k54r k55 k56f k56r k57 k58f k58r k59
global u


%% Reaction parameters for signaling pathway
kf0 = 100*(10^(-3));
kr0 = 0.05;
kf1 = 100*(10^(-3));
kr1 = 0.05;
kf2 = 20*(10^(-3));
kr2 = 0.02;
kf3 = 40*(10^(-3));
kr3 = 0.2;
k4 = 0.005;
kf5 = 8*(10^(-3));
kr5 = 0.8;
k6 = 0.4;
kf7 = 5*(10^(-3));
kr7 = 0.5;
kf8 = 20*(10^(-3));
kr8 = 0.1;
kf9 = 1*10^(-3);
kr9 = 0.2;
k10 = 0.003;
kf11 = 1*(10^(-3));
kr11 = 0.2;
k12 = 0.003;
kf13 = 0.0002*(10^(-3));
kr13 = 0.2;
k14 = 0.005;
kf15 = 1*(10^(-3));
kr15 = 0.2;
k16 = 0.005;
k17 = 0.05;
k18a = 0.01;
k18b = 400;
k19 = 0.001;
k20 = 0.01; 
kf21 = 20*(10^(-3));
kr21 = 0.1;
k22 = 0.0005;
k23 = 0.0005;
k24f = 1*10^(-2);
k24r = 0.55;
k25f = 1*10^(-2);
k25r = 0.0214;
k26f = 1.5*10^(-2);
k26r = 1.3;
k27f = 0.5;
k27r = 1*10^(-4);
k28f = 1*10^(-3);
k28r = 0.0053;
k29f = 1;
k29r = 7*10^(-4);
k30f = 7.9*10^(-3);
k30r = 0.4;
k31f = 0.023;
k31r = 2.2*10^(-4);
k32f = 0.1;
k32r = 2.45*10^(-4);
k33f = 0.3;
k33r = 2.1*10^(-2);
k34f = 6;
k34r = 0.06;
k35f = 0.0015;
k35r = 4.5*10^(-3);
vm = 1.7; 
km = 340;
k37f = 0.3;
k37r = 9*10^(-4);
k38f = 3*10^(-2);
k38r = 0.055;
k39f = 0.3;
k39r = 9*10^(-4);
k40f = 3*10^(-2);
k40r = 0.064;
k41f = 3*10^(-2);
k41r = 0.0429;
k42f = 7.17*10^(-2);
k42r = 0.2;
k43 = 1;
k44f = 1.1*10^(-2);
k44r = 0.001833;
k45 = 3.5;
k46f = 1.1*10^(-2);
k46r = 0.001833;
k47 = 2.9;
k48f = 1.43*10^(-2);
k48r = 0.8;
k49 = 0.058;
k50f = 2.5*10^(-4);
k50r = 0.5;
k51 = 0.058;
k52f = 1.1*10^(-4);
k52r = 0.033;
k53 = 16;
k54f = 1.1*10^(-4);
k54r = 0.033;
k55 = 6.7;
k56f = 1.4*10^(-2);
k56r = 0.6;
k57 = 0.27;
k58f = 5*10^(-3);
k58r = 0.5;
k59 = 0.3;

%% Initial conditions of proteins for simulation

x0 = zeros(68,1);

x0(1) = 8;
x0(3) = 0.8;
x0(4) = 12;
x0(9) = 1000;
x0(15) = 100;
x0(17) = 50;
x0(23) = 60;
x0(34) = 85;
x0(35) = 34;
x0(36) = 19000;
x0(47) = 67;
x0(50) = 67;
x0(53) = 41667;
x0(59) = 67;
x0(61) = 35000;
x0(66) = 16667;

%% IL-6 stimulation 
u = 0.383; % (nM), equal to 10 ng/ml IL6

%% Dynamic response for signal transduction induced by IL-6 in hepatocyte for 24 hours

[t y] = ode15s(@pathway_model_IL6,[0 24*3600],x0);
    
% Figure 2, (IL6-gp80-gp130-JAK*)2  profile
figure;
plot(t/3600,y(:,8),'linewidth',2)
title('Figure 2 in the paper')
xlim([0 3])
xlabel('Time (hour)','FontSize',18);
ylabel('(IL6-gp80-gp130-JAK^*)_2 (nM)','FontSize',18);
 
% Figure 3 (a), STAT3C and STAT3N*-STAT3N* profile
figure;
[AX H1 H2] = plotyy(t/3600,y(:,9),t/3600,y(:,20),'plot');
set(get(AX(1),'Ylabel'),'String','STAT3C (nM)') 
set(get(AX(2),'Ylabel'),'String','STAT3N*-STAT3N* (nM)') 
set(H1,'linewidth',2)
set(H2,'LineStyle',':','linewidth',2)
title('Figure 3 (a) in the paper')
xlabel('Time (hour)','FontSize',18);

% Figure 3 (b) SOCS3  profile
figure;
plot(t/3600,y(:,29),'linewidth',2) 
title('Figure 3 (b) in the paper')
xlabel('Time (hour)','FontSize',18);
ylabel('SOCS3 (nM)','FontSize',18);
xlim([0 24]);

  
% Figure 4, Dynamic response of STAT3C & STAT3N*-STAT3N* in SOCS3 knockout cell   
figure;
k20 = 0;
[t y] = ode15s(@pathway_model_IL6,[0 24*3600],x0);
[AX H1 H2] = plotyy(t/3600,y(:,9),t/3600,y(:,20),'plot');
set(get(AX(1),'Ylabel'),'String','STAT3C (nM)') 
set(get(AX(2),'Ylabel'),'String','STAT3N*-STAT3N* (nM)') 
title('Figure 4 in the paper')
xlabel('Time (hour)','FontSize',18);
k20 = 0.01; % reset the signaling back to normal signaling 
 
   
% Figure 5, Dynamic response of STAT3C & STAT3N*-STAT3N* with no SHP2 phosphorylation   
figure;
k34f = 0;
[t y] = ode15s(@pathway_model_IL6,[0 24*3600],x0);
[AX H1 H2] = plotyy(t/3600,y(:,9),t/3600,y(:,20),'plot');
set(get(AX(1),'Ylabel'),'String','STAT3C (nM)') 
set(get(AX(2),'Ylabel'),'String','STAT3N*-STAT3N* (nM)') 
title('Figure 5 in the paper')
xlabel('Time (hour)','FontSize',18);
k34f = 6; % reset the signaling back to normal signaling 
   
% Dynamic responses of phosphorylated SHP-2 (SHP-2*) in normal & SOCS3 knockout cell
%[t y] = ode15s(@pathway_model_IL6,[0 24*3600],x0);
%plot(t/3600,y(:,46)) 
%hold on;
%k20 = 0; % SOCS3 knockout cell
%[t y] = ode15s(@pathway_model_IL6,[0 24*3600],x0);
%plot(t/3600,y(:,46),'r') 
%k20 = 0.01; % reset the signaling back to normal signaling  


% Dynamic responses of phosphorylated Raf* in normal & SOCS3 knockout cell
%[t y] = ode15s(@pathway_model_IL6,[0 24*3600],x0);
%plot(t/3600,y(:,51)) 
%hold on;
%k20 = 0;%SOCS3 knockout cell
%[t y] = ode15s(@pathway_model_IL6,[0 24*3600],x0);
%plot(t/3600,y(:,51),'r') 
%k20 = 0.01; % reset the signaling back to normal signaling 
   

  


